class FileUser
{
    $ResponseObject
    [String]$ResponseJson

    [Int]$ProjectId
    [Int]$Id
    [String]$FirstName
    [String]$LastName
    [Int]$SourcePoolId
    [Int]$TargetPoolId
    [String]$SourceEmail
    [String]$TargetEmail
    [Int]$TargetRecipientType
    [String]$TargetLibrary
    [String]$TargetFolder
    [String]$TargetChannelName
    [String]$TargetSiteName
    [string]$IncludeMappingTable
    [string]$BulkDeleteList
    [string]$count
    [array]$jobSearch
    [int]$BatchID

    GetUserList(){
        $BodyJson = @{
            page = 1
            pageSize = 500
        }

        $Parameters = @{
            Method = "Post"
            Uri = "$global:HOSTURL/ap1/File/Displayable"
            Headers = GetHeader 
            ContentType = "application/json"
            Body = ($BodyJson | ConvertTo-Json)
        }

        $this.ResponseObject = Invoke-FrontAPI($Parameters) | ConvertFrom-Json
        $this.ResponseJson = $this.ResponseObject | ConvertTo-Json -depth 100 
    }
    
    GetFilteredUserList(){
       
        $BodyJson=@{ jobSearch=$this.jobSearch}

        $Parameters = @{
            Method = "Post"
            Uri = "$global:HOSTURL/ap1/File/Displayable"
            Headers = GetHeader 
            ContentType = "application/json"
            Body = ($BodyJson | ConvertTo-Json)
        }
      
        $this.ResponseObject = Invoke-FrontAPI($Parameters) | ConvertFrom-Json
        $this.ResponseJson = $this.ResponseObject | ConvertTo-Json -depth 100 
    }

    GetUser(){
   
        $objectId = $this.Id
        $Parameters = @{
            Method = "Get"
            Uri = "$global:HOSTURL/ap1/File/$objectId"
            Headers =GetHeader
            ContentType = "application/json"
        }
        
        $this.ResponseObject = Invoke-FrontAPI($Parameters) | ConvertFrom-Json
        $this.ResponseJson = $this.ResponseObject | ConvertTo-Json -depth 100   
    }

    SearchUser(){
   
        $BodyJson=@{ sourceEmail=$this.SourceEmail}

        $Parameters = @{
            Method = "Post"
            Uri = "$global:HOSTURL/ap1/File/FileUserSearch"
            Headers = GetHeader 
            ContentType = "application/json"
            Body = ($BodyJson | ConvertTo-Json)
        }
      
        $this.ResponseObject = Invoke-FrontAPI($Parameters) | ConvertFrom-Json
        $this.ResponseJson = $this.ResponseObject | ConvertTo-Json -depth 100  
    }
    CreateNew(){
    
        $BodyJson = @{
            firstName = $this.FirstName
            lastName = $this.LastName
            sourcePoolId = $this.SourcePoolId
            targetPoolId = $this.TargetPoolId
            sourceEmail = $this.SourceEmail
            targetEmail = $this.TargetEmail
            targetRecipientType = $this.TargetRecipientType
            targetChannelName = $this.TargetChannelName
            targetFolder =$this.TargetFolder
            targetLibrary = $this.TargetLibrary
            targetSiteName=$this.TargetSiteName
         
        }
    
        $Parameters = @{
            Method = "Post"
            Uri = "$global:HOSTURL/ap1/File"
            Headers = GetHeader
            ContentType = "application/json"
            Body = ($BodyJson | ConvertTo-Json)
        }
        
        $this.ResponseObject = Invoke-FrontAPI($Parameters) | ConvertFrom-Json
        $this.ResponseJson = $this.ResponseObject | ConvertTo-Json -depth 100   
    }
    Update(){
        
        $objectId = $this.Id
        $BodyJson = @{
            firstName = $this.FirstName
            lastName = $this.LastName
            sourcePoolId = $this.SourcePoolId
            targetPoolId = $this.TargetPoolId
            sourceEmail = $this.SourceEmail
            targetEmail = $this.TargetEmail
            targetRecipientType = $this.TargetRecipientType
            targetChannelName = $this.TargetChannelName
            targetFolder =$this.TargetFolder
            targetLibrary = $this.TargetLibrary
            targetSiteName=$this.TargetSiteName
         
        }
    
        $Parameters = @{
            Method = "Put"
            Uri = "$global:HOSTURL/ap1/File/$objectId"
            Headers = GetHeader
            ContentType = "application/json"
            Body = ($BodyJson | ConvertTo-Json)
        }
        
        $this.ResponseObject = Invoke-FrontAPI($Parameters) | ConvertFrom-Json
        $this.ResponseJson = $this.ResponseObject | ConvertTo-Json -depth 100   
    }

    Delete(){
   
        $DeleteId = $this.Id
        $Parameters = @{
            Method = "Delete"
            Uri = "$global:HOSTURL/ap1/File/$DeleteId"
            Headers =GetHeader
            ContentType = "application/json"
        }
        
        $this.ResponseObject = Invoke-FrontAPI($Parameters) | ConvertFrom-Json
        $this.ResponseJson = $this.ResponseObject | ConvertTo-Json -depth 100          
    }

    BulkDelete(){
      
        $Parameters = @{
            Method = "Put"
            Uri = "$global:HOSTURL/ap1/file/BulkDelete?includeMappingTable="+$this.IncludeMappingTable
            Headers = GetHeader
            ContentType = "application/json"
            Body = $this.BulkDeleteList   
        }
        
        $this.ResponseObject = Invoke-FrontAPI($Parameters) | ConvertFrom-Json
        $this.ResponseJson = $this.ResponseObject | ConvertTo-Json -depth 100          
    }
   
    GetBatchList(){
       
        $Parameters = @{
            Method = "Get"
            Uri = "$global:HOSTURL/ap1/File/Batch"
            Headers = GetHeader 
            ContentType = "application/json"
        }

        $this.ResponseObject = Invoke-FrontAPI($Parameters) | ConvertFrom-Json
        $this.ResponseJson = $this.ResponseObject | ConvertTo-Json -depth 100   
        
    }

    GetBatchMembers(){
       
        $returnedID=$this.BatchID
        $Parameters = @{
            Method = "Get"
            Uri = "$global:HOSTURL/ap1/File/Batch/$returnedID/members"
            Headers = GetHeader 
            ContentType = "application/json"
        }
        
        $this.ResponseObject = Invoke-FrontAPI($Parameters) | ConvertFrom-Json
        $this.ResponseJson = $this.ResponseObject | ConvertTo-Json -depth 100   
    }

    GetUserLogs(){
   
        $objectId = $this.Id
        $Parameters = @{
            Method = "Get"
            Uri = "$global:HOSTURL/ap1/File/logs/$objectId"
            Headers =GetHeader
            ContentType = "application/json"
        }
        $this.ResponseObject = Invoke-FrontAPI($Parameters) | ConvertFrom-Json
        $this.ResponseJson = $this.ResponseObject | ConvertTo-Json -depth 100           
    }
    

    GetUserStatistics(){
   
        $objectId = $this.Id
        $Parameters = @{
            Method = "Get"
            Uri = "$global:HOSTURL/ap1/File/FileStatistics/$objectId"
            Headers =GetHeader
            ContentType = "application/json"
        }
        $this.ResponseObject = Invoke-FrontAPI($Parameters) | ConvertFrom-Json
        $this.ResponseJson = $this.ResponseObject | ConvertTo-Json -depth 100           
    }
}
