#region Authentication

function GetHeader(){
  $Header = @{
      "accept" = "*/*"
      "Authorization" = "Bearer $global:BEARERTOKEN" 
      "projectId" = $global:PROJID
  }
  return $Header
}

function Invoke-FrontAPI($Params){
  # This is a generic call when invoking an API, writing results to Log
  Write-Host "Invoke-FrontAPI " $Params.Uri
  $returnStr = Invoke-WebRequest @Params 
  Return $returnStr
}

function Get-BearerToken{
  param ([string] $UserLogin, [string] $UserPW)
  #Write-Host "Get-BearerToken"
  $Header = @{
      "accept" = "*/*"
  }
  
  $BodyJson = @{
      login = $UserLogin
      password = $UserPW  
      #keepConnection = "true"  # including this throws (500) Internal Server Error
  }
  $Parameters = @{
      Method = "Post"
      
      Uri = "$global:HOSTURL/ap1/Authentication/Login"
      Headers = $Header 
      ContentType = "application/json"
      Body = ($BodyJson | ConvertTo-Json)
  }
  
  $returnStr = Invoke-FrontAPI($Parameters) | ConvertFrom-Json
  return $returnStr.token
}

#endregion


#region Projects
function GetProjects{
  param ()
  Write-Host "Get Projects" -ForegroundColor Yellow
  $Pt = [Project]::new()
  $Pt.GetAll()
  $Pt.ResponseObject.responseData
}
#endregion


#region Connectors
function GetConnectors{
  param ()
  Write-Host "Get Connectors" -ForegroundColor Yellow
  $conn = [Connector]::new()
  $conn.GetAll()
  $conn.ResponseObject.responseData
}
#endregion

#region Files
function CreateFileUser{
  param ([string] $FName, [string] $LName,[string] $SEmail,[string] $TEmail, [int] $SPool, [int] $TPool,[int] $TRecipient)
  Write-Host "Create File User" -ForegroundColor Yellow
  $fUser = [FileUser]::new()
  $fUser.FirstName = $FName
  $fUser.LastName = $LName
  $fUser.SourcePoolId = $SPool
  $fUser.TargetPoolId = $TPool
  $fUser.SourceEmail = $SEmail
  $fUser.TargetEmail = $TEmail
  $fUser.TargetRecipientType = $TRecipient 

  $fUser.CreateNew()
  $fUser.ResponseObject.responseData
  
}
function GetFileUserList{
  param ()
  Write-Host "Get File Users List" -ForegroundColor Yellow
  $fUser = [FileUser]::new()
  $fUser.GetUserList()
  #This is a sample of the properties to display, more can be added, check the ResponseData
  foreach ($item in $fUser.ResponseObject.responseData)
   {
    $item.fileuser | Select-Object -Property Id, firstname, lastname, sourceEmail, TargetEmail 
   }
}
function DeleteFileUser {
  param ([int] $Id)
  Write-Host "Delete File User: "  $Id -ForegroundColor Yellow
  $fUser = [FileUser]::new()
  $fUser.Id = $Id
  $fUser.Delete()
  $fUser.ResponseObject.responseData

}
function UpdateFileUser{
  param ([int] $Id, [string] $FName, [string] $LName,[string] $SEmail,[string] $TEmail, [int] $SPool, [int] $TPool,[int] $TRecipient)
  Write-Host "Update File User" -ForegroundColor Yellow
  $fUser = [FileUser]::new()
  $fUser.Id= $Id
  $fUser.FirstName = $FName
  $fUser.LastName = $LName
  $fUser.SourcePoolId = $SPool
  $fUser.TargetPoolId = $TPool
  $fUser.SourceEmail = $SEmail
  $fUser.TargetEmail = $TEmail
  $fUser.TargetRecipientType = $TRecipient 

  $fUser.Update()
  $fUser.ResponseObject.responseData
  
}
function GetFileUserBySourceEmail{
  param ([string] $sourceEmail)
  Write-Host "Get File User: " $sourceEmail -ForegroundColor Yellow
  $fUser = [FileUser]::new()
  $fUser.SourceEmail = $sourceEmail
  $fUser.SearchUser()
  $fUser.ResponseObject.responseData
  
}
function GetFileUserLogs{
  param ([int]$Id)
  Write-Host "Get FileUser Logs " -ForegroundColor Yellow
  $fUser = [FileUser]::new()
  $fUser.Id= $Id
  $fUser.GetUserLogs()
  foreach ($item in $fUser.ResponseObject.responseData) {
    if( $item.type -eq "User"){
 
      $item | Select-Object -Property timeStamp, message
    }
  }
}
function GetFileUserStats{
  param ([int]$Id)
  Write-Host "Get FileUser Stats " -ForegroundColor Yellow
  $fUser = [FileUser]::new()
  $fUser.Id= $Id
  $fUser.GetUserStatistics()
  $fUser.ResponseObject.responseData | Select-Object -Property startDateTime,fileTotal,fileSuccess,fileFailure, fileIgnored,folderTotal

}
function StartFileJobs{
  param ([int]$JobType, [string]$ListIDs)
  Write-Host "Start Jobs: " -ForegroundColor Yellow
  $Jobs = [Jobs]::new()
  $Jobs.StartJobsList= $ListIDs
  $Jobs.ProductType = 6 #6 is for File, do not modify
  $Jobs.JobType = $JobType 
  $Jobs.StartJobs()
  Write-Host $Jobs.ResponseJson
}
function StopFileJobs{
  param ([string]$ListIDs)
  Write-Host "Stop Jobs: " -ForegroundColor Yellow
  $Jobs = [Jobs]::new()
  $Jobs.StopJobsList= $ListIDs
  $Jobs.ProductType = 6
  $Jobs.StopJobs()
  Write-Host $Jobs.ResponseJson
}
function GetListFileBatches{
  param ()
  Write-Host "GetListBatches" -ForegroundColor Yellow
  $fUser = [FileUser]::new()
  $fUser.GetBatchList()

foreach ($item in $fUser.ResponseObject.responseData) {
 Write-Host "Batch Name: " -ForegroundColor Red 
 Write-Host $item.batch.name
 Write-Host "Batch ID: " -ForegroundColor Red 
 Write-Host $item.batch.Id
 Write-Host "# Members in the Batch: " -ForegroundColor Red  
 Write-Host $item.batchMemberCount
 Write-Host " " 
}
}
function StartFileBatchJobs{
  param ([int] $Jobtype, [int]$Id)
  Write-Host "Start Batch Jobs: " -ForegroundColor Yellow
  $Jobs = [Jobs]::new()
  $Jobs.BatchId= $Id
  $Jobs.ProductType = 6 #6 is for File, do not modify
  $Jobs.JobType = $JobType 
  $Jobs.StartBatchJobs()
  Write-Host $Jobs.ResponseJson
}
function StopFileBatchJobs{
  param ([int]$Id)
  Write-Host "Start Batch Jobs: " -ForegroundColor Yellow
  $Jobs = [Jobs]::new()
  $Jobs.BatchId= $Id
  $Jobs.ProductType = 6 #6 is for File, do not modify
  $Jobs.StopBatchJobs()
  Write-Host $Jobs.ResponseJson
}

#endregion


#region Groups
function GetGroupList{
  param ()
  Write-Host "Get Group List" -ForegroundColor Yellow
  $gUser = [GroupUser]::new()
  $gUser.GetGroupList()
  #This is a sample of the properties to display, more can be added, check the ResponseData
  foreach ($item in $gUser.ResponseObject.responseData)
   {
    $item.teamSiteEntry| Select-Object -Property Id, sourceName, sourceEmailAddress,targetName, targetEmailAddress 
   }
}

function CreateGroupUser{
  param ( [int] $SPool, [int] $SRecipient, [string] $SName,[string] $SEmail,[string] $SId,[int] $TPool,[int] $TRecipient,[string] $TName, [string] $TEmail )
  Write-Host "Create Group User" -ForegroundColor Yellow
  $gUser = [GroupUser]::new()
  $gUser.SourcePoolId= $SPool
  $gUser.TargetPoolId=$TPool
  $gUser.SourceName = $SName
  $gUser.SourceId = $SId
  $gUser.SourceEmail = $SEmail
  $gUser.SourceRecipientType = $SRecipient
  $gUser.TargetName = $TName
  $gUser.TargetEmail = $TEmail
  $gUser.TargetRecipientType = $TRecipient

  $gUser.CreateNew()
  $gUser.ResponseObject.responseData
  
}
function UpdateGroupUser{
  param ([int] $Id, [int] $SPool, [int] $SRecipient, [string] $SName,[string] $SEmail,[string] $SId,[int] $TPool,[int] $TRecipient,[string] $TName, [string] $TEmail )
  Write-Host "Update Group User" -ForegroundColor Yellow
  $gUser = [GroupUser]::new()
  $gUser.Id = $Id
  $gUser.SourcePoolId= $SPool
  $gUser.TargetPoolId=$TPool
  $gUser.SourceName = $SName
  $gUser.SourceId = $SId
  $gUser.SourceEmail = $SEmail
  $gUser.SourceRecipientType = $SRecipient
  $gUser.TargetName = $TName
  $gUser.TargetEmail = $TEmail
  $gUser.TargetRecipientType = $TRecipient

  $gUser.Update()
  $gUser.ResponseObject.responseData
  
}

function BulkDeleteGroups {
  param ([string] $IdsList)
  Write-Host "Bulk Delete Groups: "  $IdsList -ForegroundColor Yellow
  $gUser = [GroupUser]::new()
  $gUser.BulkDeleteList = $IdsList
  $gUser.BulkDelete()
  $gUser.ResponseObject.responseData
  Write-Host "Bulk Delete Ended "  -ForegroundColor Yellow

}

function GetGroupBySourceName{
  param ([string] $sourceName)
  Write-Host "Get Group User: " $sourceName -ForegroundColor Yellow
  $gUser = [GroupUser]::new()
  $gUser.SourceName = $sourceName
  $gUser.SearchUser()
  $gUser.ResponseObject.responseData
  
}

function GetGroupUserLogs{
  param ([int]$Id)
  Write-Host "Get GroupUser Logs " -ForegroundColor Yellow
  $gUser = [GroupUser]::new()
  $gUser.Id= $Id
  $gUser.GetUserLogs()
  foreach ($item in $gUser.ResponseObject.responseData) {
    if( $item.type -eq "User"){
 
      $item | Select-Object -Property timeStamp, message
    }
  }
}

function GetGroupUserStats{
  param ([int]$Id)
  Write-Host "Get GroupUser Logs " -ForegroundColor Yellow
  $gUser = [GroupUser]::new()
  $gUser.Id= $Id
  $gUser.GetUserStatistics()
  $gUser.ResponseObject.responseData

}

function StartGroupJobs{
  param ([int]$JobType, [string]$ListIDs)
  Write-Host "Start Jobs: " -ForegroundColor Yellow
  $Jobs = [Jobs]::new()
  $Jobs.StartJobsList= $ListIDs
  $Jobs.ProductType = 8 #8 is for File, do not modify
  $Jobs.JobType = $JobType 
  $Jobs.StartJobs()
  Write-Host $Jobs.ResponseJson
}

function StopGroupJobs{
  param ([string]$ListIDs)
  Write-Host "Stop Jobs: " -ForegroundColor Yellow
  $Jobs = [Jobs]::new()
  $Jobs.StopJobsList= $ListIDs
  $Jobs.ProductType = 8
  $Jobs.StopJobs()
  Write-Host $Jobs.ResponseJson
}

function GetListGroupBatches{
  param ()
  Write-Host "GetListBatches" -ForegroundColor Yellow
  $gUser = [GroupUser]::new()
  $gUser.GetBatchList()
     foreach ($item in $gUser.ResponseObject.responseData) {
        Write-Host "Batch Name: " -ForegroundColor Red 
        Write-Host $item.batch.name
        Write-Host "Batch ID: " -ForegroundColor Red 
        Write-Host $item.batch.Id
        Write-Host "# Members in the Batch: " -ForegroundColor Red  
        Write-Host $item.batchMemberCount
        Write-Host " " 
}
}

function StartGroupBatchJobs{
  param ([int] $Jobtype, [int]$Id)
  Write-Host "Start Batch Jobs: " -ForegroundColor Yellow
  $Jobs = [Jobs]::new()
  $Jobs.BatchId= $Id
  $Jobs.ProductType = 8 #8 is for Group, do not modify
  $Jobs.JobType = $JobType 
  $Jobs.StartBatchJobs()
  Write-Host $Jobs.ResponseJson
}
function StopGroupBatchJobs{
  param ([int]$Id)
  Write-Host "Start Batch Jobs: " -ForegroundColor Yellow
  $Jobs = [Jobs]::new()
  $Jobs.BatchId= $Id
  $Jobs.ProductType = 8 #8 is for Group, do not modify
  $Jobs.StopBatchJobs()
  Write-Host $Jobs.ResponseJson
}
#endregion


#region Sites

function GetSiteList{
  param ()
  Write-Host "Get Site List" -ForegroundColor Yellow
  $sUser = [SiteUser]::new()
  $sUser.GetSiteList()
  #This is a sample of the properties to display, more can be added, check the ResponseData
  foreach ($item in $sUser.ResponseObject.responseData)
   {
    $item.teamSiteEntry| Select-Object -Property Id, sourceName, sourceId,targetName, targetUrl 
   }
}

function CreateSiteUser{
  param ( [int] $SPool, [int] $SRecipient, [string] $SName,[string] $SId,[int] $TPool,[int] $TRecipient,[string] $TName, [string] $TUrl )
  Write-Host "Create Site User" -ForegroundColor Yellow
  $sUser = [SiteUser]::new()
  $sUser.SourcePoolId= $SPool
  $sUser.TargetPoolId=$TPool
  $sUser.SourceName = $SName
  $sUser.SourceId = $SId
  $sUser.SourceRecipientType = $SRecipient
  $sUser.TargetName = $TName
  $sUser.TargetUrl= $TUrl
  $sUser.TargetRecipientType = $TRecipient

  $sUser.CreateNew()
  $sUser.ResponseObject.responseData
  
}

function UpdateSiteUser{
  param ([int] $Id, [int] $SPool, [int] $SRecipient, [string] $SName,[string] $SId,[int] $TPool,[int] $TRecipient,[string] $TName, [string] $TUrl )
  Write-Host "Update Site User" -ForegroundColor Yellow
  $sUser = [SiteUser]::new()
  $sUser.SourcePoolId= $SPool
  $sUser.TargetPoolId=$TPool
  $sUser.SourceName = $SName
  $sUser.SourceId = $SId
  $sUser.SourceRecipientType = $SRecipient
  $sUser.TargetName = $TName
  $sUser.TargetUrl= $TUrl
  $sUser.TargetRecipientType = $TRecipient

  $sUser.CreateNew()
  $sUser.ResponseObject.responseData
  
}

function BulkDeleteSites {
  param ([string] $IdsList)
  Write-Host "Bulk Delete Sites: "  $IdsList -ForegroundColor Yellow
  $sUser = [SiteUser]::new()
  $sUser.BulkDeleteList = $IdsList
  $sUser.BulkDelete()
  $sUser.ResponseObject.responseData
  Write-Host "Bulk Delete Ended "  -ForegroundColor Yellow

}

function GetSiteBySourceName{
  param ([string] $sourceName)
  Write-Host "Get Site User: " $sourceName -ForegroundColor Yellow
  $sUser = [SiteUser]::new()
  $sUser.SourceName = $sourceName
  $sUser.SearchUser()
  $sUser.ResponseObject.responseData
  
}

function GetSiteUserLogs{
  param ([int]$Id)
  Write-Host "Get Site User Logs " -ForegroundColor Yellow
  $sUser = [SiteUser]::new()
  $sUser.Id= $Id
  $sUser.GetUserLogs()
  foreach ($item in $sUser.ResponseObject.responseData) {
    if( $item.type -eq "User"){
 
      $item | Select-Object -Property timeStamp, message
    }
  }
}

function GetSiteUserStats{
  param ([int]$Id)
  Write-Host "Get Site User Stats " -ForegroundColor Yellow
  $sUser = [SiteUser]::new()
  $sUser.Id= $Id
  $sUser.GetUserStatistics()
  $sUser.ResponseObject.responseData

}

function StartSiteJobs{
  param ([int]$JobType, [string]$ListIDs)
  Write-Host "Start Jobs: " -ForegroundColor Yellow
  $Jobs = [Jobs]::new()
  $Jobs.StartJobsList= $ListIDs
  $Jobs.ProductType = 7 #7 is for File, do not modify
  $Jobs.JobType = $JobType 
  $Jobs.StartJobs()
  Write-Host $Jobs.ResponseJson
}

function StopSiteJobs{
  param ([string]$ListIDs)
  Write-Host "Stop Jobs: " -ForegroundColor Yellow
  $Jobs = [Jobs]::new()
  $Jobs.StopJobsList= $ListIDs
  $Jobs.ProductType = 7
  $Jobs.StopJobs()
  Write-Host $Jobs.ResponseJson
}

function GetListSiteBatches{
  param ()
  Write-Host "GetListBatches" -ForegroundColor Yellow
  $sUser = [SiteUser]::new()
  $sUser.GetBatchList()
     foreach ($item in $sUser.ResponseObject.responseData) {
        Write-Host "Batch Name: " -ForegroundColor Red 
        Write-Host $item.batch.name
        Write-Host "Batch ID: " -ForegroundColor Red 
        Write-Host $item.batch.Id
        Write-Host "# Members in the Batch: " -ForegroundColor Red  
        Write-Host $item.batchMemberCount
        Write-Host " " 
}
}

function StartSiteBatchJobs{
  param ([int] $Jobtype, [int]$Id)
  Write-Host "Start Batch Jobs: " -ForegroundColor Yellow
  $Jobs = [Jobs]::new()
  $Jobs.BatchId= $Id
  $Jobs.ProductType = 7 #7 is for Sites, do not modify
  $Jobs.JobType = $JobType 
  $Jobs.StartBatchJobs()
  Write-Host $Jobs.ResponseJson
}
function StopSiteBatchJobs{
  param ([int]$Id)
  Write-Host "Start Batch Jobs: " -ForegroundColor Yellow
  $Jobs = [Jobs]::new()
  $Jobs.BatchId= $Id
  $Jobs.ProductType =  7 #7 is for Sites, do not modify
  $Jobs.StopBatchJobs()
  Write-Host $Jobs.ResponseJson
}

#endregion

#region Mails
function CreateMailUser{
  param ([string] $FName, [string] $LName,[string] $SEmail,[int] $SRecipient,[string] $TEmail, [int] $SPool, [int] $TPool,[int] $TRecipient)
  Write-Host "Create Mail User" -ForegroundColor Yellow
  $mUser = [MailUser]::new()
  $mUser.FirstName = $FName
  $mUser.LastName = $LName
  $mUser.SourcePoolId = $SPool
  $mUser.TargetPoolId = $TPool
  $mUser.SourceEmail = $SEmail
  $mUser.TargetEmail = $TEmail
  $mUser.TargetRecipientType = $TRecipient 
  $mUser.SourceRecipientType = $SRecipient 
  $muser.CreateNew()
  $mUser.ResponseObject.responseData
  
}
function UpdateMailUser{
  param ([int] $Id, [string] $FName, [string] $LName,[string] $SEmail,[int] $SRecipient,[string] $TEmail, [int] $SPool, [int] $TPool,[int] $TRecipient)
  Write-Host "Update Mail User" -ForegroundColor Yellow
  $mUser = [MailUser]::new()
  $mUser.Id = $Id
  $mUser.FirstName = $FName
  $mUser.LastName = $LName
  $mUser.SourcePoolId = $SPool
  $mUser.TargetPoolId = $TPool
  $mUser.SourceEmail = $SEmail
  $mUser.TargetEmail = $TEmail
  $mUser.TargetRecipientType = $TRecipient 
  $mUser.SourceRecipientType = $SRecipient 
  $muser.Update()
  $mUser.ResponseObject.responseData
  
}

function BulkDeleteMails {
  param ([string] $IdsList)
  Write-Host "Bulk Delete Mails: "  $IdsList -ForegroundColor Yellow
  $mUser = [MailUser]::new()
  $mUser.BulkDeleteList = $IdsList
  $mUser.BulkDelete()
  $mUser.ResponseObject.responseData
  Write-Host "Bulk Delete Ended "  -ForegroundColor Yellow

}

function GetMailUserBySourceEmail{
  param ([string] $sourceEmail)
  Write-Host "Get Mail User: " $sourceEmail -ForegroundColor Yellow
  $mUser = [MailUser]::new()
  $mUser.SourceEmail = $sourceEmail
  $mUser.SearchUser()
  $mUser.ResponseObject.responseData
  
}
function GetMailUserLogs{
  param ([int]$Id)
  Write-Host "Get Mail User Logs " -ForegroundColor Yellow
  $mUser = [MailUser]::new()
  $mUser.Id= $Id
  $mUser.GetUserLogs()
  foreach ($item in $mUser.ResponseObject.responseData) {
    if( $item.type -eq "User"){
 
      $item | Select-Object -Property timeStamp, message
    }
  }
}
function GetMailUserStats{
  param ([int]$Id)
  Write-Host "Get Mail User Logs " -ForegroundColor Yellow
  $mUser = [MailUser]::new()
  $mUser.Id= $Id
  $mUser.GetUserStatistics()
  $mUser.ResponseObject.responseData 

}


function StartMailJobs{
  param ([int]$JobType, [string]$ListIDs)
  Write-Host "Start Jobs: " -ForegroundColor Yellow
  $Jobs = [Jobs]::new()
  $Jobs.StartJobsList= $ListIDs
  $Jobs.ProductType = 5 #5 is for Mail, do not modify
  $Jobs.JobType = $JobType 
  $Jobs.StartJobs()
  Write-Host $Jobs.ResponseJson
}
function StopMailJobs{
  param ([string]$ListIDs)
  Write-Host "Stop Jobs: " -ForegroundColor Yellow
  $Jobs = [Jobs]::new()
  $Jobs.StopJobsList= $ListIDs
  $Jobs.ProductType = 5
  $Jobs.StopJobs()
  Write-Host $Jobs.ResponseJson
}

function GetListMailBatches{
  param ()
  Write-Host "GetListBatches" -ForegroundColor Yellow
  $mUser = [MailUser]::new()
  $mUser.GetBatchList()
     foreach ($item in $mUser.ResponseObject.responseData) {
        Write-Host "Batch Name: " -ForegroundColor Red 
        Write-Host $item.batch.name
        Write-Host "Batch ID: " -ForegroundColor Red 
        Write-Host $item.batch.Id
        Write-Host "# Members in the Batch: " -ForegroundColor Red  
        Write-Host $item.batchMemberCount
        Write-Host " " 
}
}

function StartMailBatchJobs{
  param ([int] $Jobtype, [int]$Id)
  Write-Host "Start Batch Jobs: " -ForegroundColor Yellow
  $Jobs = [Jobs]::new()
  $Jobs.BatchId= $Id
  $Jobs.ProductType = 5
  $Jobs.JobType = $JobType 
  $Jobs.StartBatchJobs()
  Write-Host $Jobs.ResponseJson
}
function StopMailBatchJobs{
  param ([int]$Id)
  Write-Host "Start Batch Jobs: " -ForegroundColor Yellow
  $Jobs = [Jobs]::new()
  $Jobs.BatchId= $Id
  $Jobs.ProductType = 5
  $Jobs.StopBatchJobs()
  Write-Host $Jobs.ResponseJson
}

#endregion




































































